declare module BA.Ui.Pages {
    class PageTools {
        static IsGMapsLoaded: boolean;
        private static _DragAndDropRules;
        private static _DragInProgress;
        private static _AcceptsResults;
        private static _SavePageCustomizationsTimeoutHandler;
        private static _UnsavedDragAndDrop;
        private static _MustSavePageCustomizationsOnLoad;
        /**
         * Adds the given instance of BA.Ui.Widgets.Widget to the page displayed in the current tab, if any.
         *
         * @param widget Instance of BA.Ui.Widgets.Widget to add to the page
         * @param inWidgetCatalogue If the widget is being rendered in the catalogue.
         */
        static AddWidgetToCurrentPage(widget: BA.Ui.Widgets.Widget, inWidgetCatalogue?: boolean): void;
        /**
         * Moves the given instance of BA.Ui.Widgets.Widget to the page's catalogue.
         *
         * @param widget instance of BA.Ui.Widgets.Widget to move to the page's catalogue
         * @param forceRemove if the widget must be removed regardless of its beforeRemoving result
         */
        static RemoveWidgetFromCurrentPage(widget: Widgets.Widget, forceRemove?: boolean, animate?: boolean): void;
        /**
         * Returns the page displayed in the current tab, if any.
         */
        static GetCurrentPage(): Page;
        /**
         * Returns the page with Id equal to the parameter, if any.
         *
         * @param id of the page to look for
         */
        static GetPage(id: BA.Classes.Guid): Page;
        /**
         * Returns the page with configurationGuid equal to the parameter, if any.
         *
         * @param configId of the page to look for
         */
        static GetPageByConfigurationGuid(configId: BA.Classes.Guid): Page;
        /**
         * Returns a string containing the json of the parameter of the page
         */
        static GetPageParameterJsonString(): string;
        /**
         * Returns the parameter object of the page
         */
        static GetPageParameter<T extends BA.Ui.Widgets.Parameters.WidgetParameterBase>(): T;
        /**
         * DO NOT USE THIS.
         * Internal function that changes the parameter of the page
         *
         * @param changedBy id of the widget that modified the parameter
         * @param newParameter the new parameter for the page
         */
        static ChangePageParameter(changedBy: string, newParameter?: BA.Ui.Widgets.Parameters.WidgetParameterBase): void;
        /**
         * Returns the BA.Ui.Widgets.Widget in the current page with Id equal to the parameter, if any.
         *
         * @param id of the widget to look for
         */
        static GetWidgetInCurrentPage(id: BA.Classes.Guid): BA.Ui.Widgets.Widget;
        /**
         * Given an element's JQuery object, if said element is rendered within a widget, this function returns the container widget.
         *
         * @param $element
         */
        static GetContainerWidget<T extends BA.Ui.Widgets.Widget>($element: JQuery): T;
        /**
         * Given an element's JQuery object, if said element is rendered within a widget, this function returns the container widgets JQuery object.
         *
         * @param $element
         */
        static GetContainerWidgetJQ($element: JQuery): JQuery;
        /**
         * Given an element's JQuery object, if said element is rendered within a widget, this function returns true. Otherwise it returns false.
         *
         * @param $element
         */
        static IsInWidget($element: JQuery): boolean;
        /**
         * Initializes the drag and drop in the page.
         */
        static InitDragAndDrop(): void;
        /**
         * Saves the current distribution of widgets in drag and drop areas
         * in form of page customizations.
         *
         * @param delayed if it should be saved with a delay of 5 seconds.
         */
        static SavePageCustomizations(delayed?: boolean): void;
        private static PostPageCustomizations;
        static DeletePageCustomizationsOfCurrentUser(async: boolean): void;
        private static GetDragAndDropWidgetLocations;
        /**
         * If calling this method before the page is loaded, the customizations
         * will be saved when initializing the drag and drop in the page.
         */
        static SavePageCustomizationsOnLoad(): void;
        static CheckHeightIncompatibility(widget?: JQuery): void;
        static OnGoogleMapsLoaded(): void;
    }
}
