declare module BA.Ui.TabController {
    class Tab {
        private _Title;
        private _Icon;
        private _IconPrefix;
        private _IconSuffix;
        private _IconSuffixPinNeedle;
        private _DefaultIcon;
        private _Url;
        private _UrlForIFrame;
        private _TabReference;
        private _IsLoaded;
        private _IsActive;
        private _IsPinned;
        private _Guid;
        private _IframeName;
        private _Owner;
        private _Dirty;
        private _IsDelayed;
        private _TimeoutId;
        private _PreviousTab;
        private _OpenBehaviorModel;
        private _AutoRefresh;
        private _ForcedAutoRefresh;
        private _TabBarCommandButtonClickHandler;
        private _iframeElement;
        TabBarCommandButtonTitle: string;
        IsMassOperationTab: Boolean;
        MassOperationWorkItemId: string;
        TabProcessId: string;
        AdditionalData: any;
        ActivatedEvent: CustomEvent;
        _Page: BA.Ui.Pages.Page;
        /**
         *  The constructor for a new tab. Initializes the properties and creates the iframe
         */
        constructor(owner: Controller, url: string, tabReference: string, title: string, icon: string, guid: BA.Classes.Guid, delayLoading?: boolean, showAnimation?: boolean, isPinned?: boolean);
        GetEventName(): string;
        /**
         * Creates the html string for the tab header.
         * @param visible default in true, will make this header visible and with all its content. Needed for tab removes.
         */
        TabHTMLString(visible?: boolean): string;
        /**
         * Returns true if the tab has been activated.
         */
        get IsActive(): boolean;
        get CanClose(): boolean;
        get IsPage(): boolean;
        /**
         * Activates the tab. That means, it deactivates the current active one and does the necessary
         * visual changes on the site to see this tab as active. This includes updating the document.title.
         */
        Activate(): void;
        UpdateCommandButtonVisibilityAndTooltip(): void;
        /**
         * Executes what needs to be executed after the tab has been loaded. Loading the form content, handling
         * the open behaviour among others.
         */
        PostLoad(): void;
        /**
         * When executed, if the tab has been marked as autorefresh or needs a forced autorefresh, it will trigger
         * the onShow event of the iframe.
         */
        ExecuteAutoRefresh(): void;
        /**
         *  Does the necessary visual changes to be shown as deactivated.
         */
        Deactivate(): void;
        /**
         * Removes the IFrame from the UI and the tab header. It adds another tab header, invisible, to act as dummy
         * until the tab bar is updated, to improve the UX during the closing of tabs.
         */
        Remove(): void;
        /**
         * Setter of the tab´s Page.
         */
        set Page(value: BA.Ui.Pages.Page);
        /**
         * Getter of the tab´s page.
         */
        get Page(): BA.Ui.Pages.Page;
        /**
         * Getter of the tab´s title.
         */
        get Title(): string;
        /**
         * Setter of the tab´s title. When set, it will update the ui accordingly and save the current status of the tabs list.
         */
        set Title(value: string);
        /**
         * Getter of the tab´s IsPinned property.
         */
        get IsPinned(): boolean;
        /**
         * Setter of the tab´s title. When set, it will update the ui accordingly and save the current status of the tabs list.
         */
        set IsPinned(value: boolean);
        /**
         * Getter of the tab´s icon.
         */
        get Icon(): string;
        /**
         * Setter of the tab´s icon. When set, it will update the ui accordingly and save the current status of the tabs list.
         */
        set Icon(value: string);
        /**
         * Getter of the tab´s url.
         */
        get Url(): string;
        /**
         * Setter of the tab´s url.
         */
        set Url(url: string);
        /**
         * Getter of the tab´s reference. This is used as identifier of the tabs in the controller.
         */
        get TabReference(): string;
        /**
         * Setter of the tab´s reference. This is used as identifier of the tabs in the controller.
         */
        set TabReference(ref: string);
        /**
         * The IFrameName ID name of the Tab (readonly)
         */
        get IFrameName(): string;
        /**
         * True, if the Tab is loaded
         */
        get IsLoaded(): boolean;
        /**
         * Setter of the tabs IsLoaded property.
         */
        set IsLoaded(value: boolean);
        /**
         * Getter of the tab´s Guid
         */
        get Guid(): BA.Classes.Guid;
        /**
         * Setter of the tab´s Guid
         */
        set Guid(value: BA.Classes.Guid);
        /**
         * Owner (Controller.ts instance) of Tab (readonly)
         */
        get Owner(): Controller;
        /**
         * Returns true if the tab is in the list of tabs of its Owner and the Owner has only one tab
         */
        IsLastTab(): boolean;
        /**
         * Returns true if its url is the start page url
         */
        IsStartPage(): boolean;
        /**
         * Returns true if the open behaviour of the tab is not to block its opening
         */
        get ShowAllowed(): boolean;
        /**
         * If the tab has been marked as dirty by other methods
         */
        get Dirty(): boolean;
        /**
         * Marks the tab as dirty
         */
        set Dirty(value: boolean);
        /**
         * Gets the tab that was active before this tab
         */
        get PreviousTab(): Tab;
        /**
         * Sets the tab that was active before this tab
         */
        set PreviousTab(value: Tab);
        /**
         * Should the tab be refreshed, if it is loaded
         */
        get AutoRefresh(): boolean;
        /**
         * Sets whether the tab should be refreshed, if it is loaded
         */
        set AutoRefresh(value: boolean);
        /**
         * Should the tab be refreshed, if it is loaded, even if it normally is not refreshed
         */
        get ForcedAutoRefresh(): boolean;
        /**
         * Sets whether the tab should be refreshed, if it is loaded
         */
        set ForcedAutoRefresh(value: boolean);
        /**
         * Update the given parts of the form
         */
        UpdateDocumentParts(keys: string[]): void;
        /**
         * Update the given parts of the form
         */
        UpdateGridViews(gridUINames: string[]): void;
        /**
         * Returns the Title of the Tab. Include * if there is a change
         */
        GetTitle(): string;
        /**
         * Updates the title of the tab in the ui and the browser tab
         */
        UpdateTitle(): void;
        /**
         * Updates the icon of the tab in the ui
         */
        UpdateIcon(): void;
        /**
         * Load the page if it is delayed
         */
        LoadDelayed(): void;
        /**
         * Performs a new load of the url of the tab reloading the iframe
         */
        FullRefresh(): void;
        /**
         * Is Page delayed
         */
        get Delayed(): boolean;
        /**
         * Resets some internal settings on Login
         */
        ResetAfterLogin(): void;
        /**
         * Handle e.g. show popup or toastr
         */
        HandleOpenBehavior(): void;
        /**
         * Set what method to execute on click to the tab bar button for content settings while this tab is active.
         */
        set TabBarCommandButtonClickHandler(handler: Function);
        /**
         * On click to the tab bar button for content settings while this tab is active, this method will execute the corresponding function, if any.
         */
        HandleTabBarCommandButtonClick(e: any): void;
        /**
         * Fatal Error Handling: Shows the erros page generated by the server after 60 seconds (if not handled by the application).
         */
        private StartTimeout;
        /**
         * Cancel the timeout for error handling
         */
        private CancelTimeout;
        /**
         * Shows fatal error
         */
        private ShowFatalError;
        private AddRequiredUrlParams;
    }
}
