declare module BA.Ui.Widgets {
    /**Class for GridView Widget*/
    class GridViewWidget extends Widget {
        private _alreadyLoaded;
        private _selectionChangedTimeout;
        private _maxSelectedInParameter;
        Init(): void;
        /**
         * Attach the events needed for the drag and drop interaction of google maps widgets.
         */
        AttachDragAndDropEvents(): void;
        Unload(): void;
        /**
         * When the content is loaded the grid view needs to be resized.
         */
        OnContentLoaded(): void;
        OnPreviewContentLoaded(): void;
        /**
         * Overrides the default handling of the DefaultFocus on widgets to delegate it to the grid view.
         *
         * @param callback Not used in this case.
         */
        DefaultFocus(callback?: Function): void;
        /**
         * When the selection changes, the GridViewWidget sets the selection as parameter to be read by other widgets.
         *
         * @param grid The grid whose selection is changed.
         */
        OnGridSelectionChanged(grid: BAClientGridView): void;
        /**
         *
         * @param anchorId
         * @param gridName
         * @param gridTitle
         * @param gridConfigurationGuid
         * @returns
         */
        static InsertMenuBarForGrid(anchorId: string, gridName: string, gridTitle: string, gridConfigurationGuid: string): void;
        /**
         * Returns the current grid view object.
         */
        private GetCurrentGrid;
        /**
         * Adjusts the size of the current grid view.
         */
        private AdjustGridViewSize;
        /**
         * Creates the GridSelectionWidgetParameter object.
         *
         * @param grid The grid whose selection is used for the parameter.
         */
        private GetGridSelectionParameter;
        /**
         * Creates a OrmData object out of a GridRowItem.
         *
         * @param selectionItem The GridRowItem to be used to create the OrmData object.
         */
        private GetOrmDataFromGridRowItem;
        /**
         * When the widget is expanded the grid view needs to be resized.
         */
        OnExpanded(): void;
        /**
         * When the widget is maximized the grid view needs to be resized.
         */
        OnMaximized(): void;
        /**
         * When the widget's size is restored the grid view needs to be resized.
         */
        OnSizeRestored(): void;
        OnWidgetSettingsChanged(isSuccess: boolean, changesJson: string, triggerContentReload?: boolean): void;
        /**
         * Overrides the standard widget refresh function in order to ask for confirmation if the form has been edited
         *
         * @param blockWidget
         * @param async
         */
        Refresh(blockWidget?: boolean, async?: boolean): void;
    }
}
