declare module BA.Ui.Widgets {
    class WidgetSettingsUtils {
        /**
         * Set a single widget Setting
         * @param option the name of the widget setting
         * @param widgetId the id of the widget
         * @param pageConfigId the id of the page configuration
         * @param value the data to be saved
         * @param tabId the Tab Id needed for the WidgetInTab scope
         * @param onDone function to be called on done
         * @param onError function to be called on error
         */
        static SetWidgetSetting(option: string, widgetId: BA.Classes.Guid, pageConfigId: BA.Classes.Guid, value: any, tabId?: BA.Classes.Guid | null, onDone?: (response: any) => void, onError?: (response: any) => void): JQueryPromise<any>;
        /**
         * Set all possible widget settings for a specific widget for the current user
         * @param widgetId Id of the widget
         * @param pageConfigId Id of the page configuration
         */
        static SetDefaultWidgetSettings(widgetId: BA.Classes.Guid, pageConfigId: BA.Classes.Guid): JQueryXHR;
        /**
         * Get a single widget setting by key
         * @param option the name of the widget setting
         * @param widgetId the id of the widget
         * @param pageConfigId the id of the page configuration
         * @param tabId the Tab Id needed for the WidgetInTab scope
         * @param onDone function to be called on done
         * @param onError function to be called on error
         */
        static GetWidgetSetting(option: string, widgetId: BA.Classes.Guid, pageConfigId: BA.Classes.Guid, tabId?: BA.Classes.Guid | null, onDone?: (response: any) => void, onError?: (response: any) => void): any;
        /**
         * Remove a single widget setting by key
         * @param option the name of the widget setting
         * @param widgetId the id of the widget
         * @param pageConfigId the id of the page configuration
         * @param tabId the Tab Id needed for the WidgetInTab scope
         * @param onDone function to be called on done
         * @param onError function to be called on error
         */
        static RemoveWidgetSetting(option: string, widgetId: BA.Classes.Guid, pageConfigId: BA.Classes.Guid, tabId?: BA.Classes.Guid | null, onDone?: (response: any) => void, onError?: (response: any) => void): any;
        /**
         * Restore all widget settings
         * @param widgetId Id of the widget whose settings will be restored
         * @param pageConfigId id of the page configuration containing the widget
         * @param forceRemoveSkipRender indicator if widget settings that aren't editable in the dialog should also be removed
         * @param onDone function to be called on done
         * @param onError function to be called on error
         */
        static RemoveAllWidgetSettings(widgetId: BA.Classes.Guid, pageConfigId: BA.Classes.Guid, forceRemoveSkipRender?: boolean, onDone?: (response: any) => void, onError?: (response: any) => void): any;
        /**
         * Function to reset the UI settings of all users for a specific page from within the designer
         * @param button the button that was clicked on
         * @param evt the event
         * */
        static RemoveWidgetSettings(button: any, evt: ASPxClientButtonClickEventArgs): void;
        /**
         * Function to be called after interaction with the widget ui settings dialog (besides cancel)
         * @param button The Dialog button pressed
         * @param evt The event
         * */
        static WidgetSettingsDialogClose(button: BA.Ui.Dialog.BADialogButton, evt: ASPxClientButtonClickEventArgs): void;
        /**
         * Function to perform Action after Dialog Button Click
         * @param popup The dialog popup
         * */
        static WidgetSettingsDialogPerformAction(popup: BA.Ui.Dialog.BADialogPopup): void;
    }
}
